#ifdef MODBUS_SUPPORT_ENABLED
#ifndef _IEMDB_H_
#define _IEMDB_H_

#include <silecs-communication/protocol/core/ietype.h>
#include <modbus.h>

/*----------------------------------------------------------*/
/* Time funtion
 * IeMdbSetTime: Convert time_t epoch date to PLC SCHNEIDER
 * format.
 *
 * Details:
 * PLC SCHNEIER format is coded on 8 bytes BCD
 * format:
 *
 *  0      1      2      3      4      5     6     7 
 *  SC     --     HH     MN     MM     DD    YY    YY
 *
 *  byte 1 is used by gateway to synchronize time setting.
 */
void IeMdbSetTime(unsigned char *dt, time_t epoch);  // to PLC

/*----------------------------------------------------------*/
/* Time funtion
 * IeMdbGetTime: Convert PLC SCHNEIDER format to lynxOS 
 * time_t format.
 *
 * Details:
 * PLC SCHNEIER format is coded on 8 bytes BCD
 * format:
 *
 *  0      1        2      3      4      5     6     7 
 *  SC     SC/100   HH     MN     MM     DD    YY    YY
 *
 */
double IeMdbGetTime(unsigned char *dt); // from PLC

/*----------------------------------------------------------*/
/* This function send a data segment to the PLC using the
 * MODBUS protocole.
 * 'ctx': write channel id of the MB connection
 * 'dataAddr': target address of the data segment within the PLC memory
 * 'dataSize': byte size of the data segment to be sent
 * 'dataBuffer': buffer of the data to be sent
 * return 0 or <0 on error (see constant error)
 */
int IeMBwriteData(modbus_t* ctx, uint16_t dataAddr, uint16_t dataSize, uint8_t* dataBuffer);

/*----------------------------------------------------------*/
/* This function read a data segment from the PLC using the
 * MODBUS protocole.
 * 'ctx': read channel id of the MB connection
 * 'dataAddr': address of the data segment within the PLC memory
 * 'dataSize': byte size of the data segment to be read
 * 'dataBuffer': buffer to store the data
 * return 0 or <0 on error (see constant error)
 */
int IeMBreadData(modbus_t* ctx, uint16_t dataAddr, uint16_t dataSize, uint8_t* dataBuffer);

#endif /* _IEMDB_H_ */
#endif //MODBUS_SUPPORT_ENABLED
